@@ -1,5 +1,7 @@
 """
-Main interface for ec2-instance-connect service client
+Type annotations for ec2-instance-connect service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
 
 Usage::
 
@@ -45,7 +47,8 @@ class Exceptions:
 
 class EC2InstanceConnectClient:
     """
-    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
     """
 
     meta: ClientMeta
@@ -53,7 +56,8 @@ class EC2InstanceConnectClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#can-paginate)
         """
 
     def generate_presigned_url(
@@ -64,19 +68,22 @@ class EC2InstanceConnectClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#generate-presigned-url)
         """
 
     def send_serial_console_ssh_public_key(
         self, InstanceId: str, SSHPublicKey: str, SerialPort: int = None
     ) -> SendSerialConsoleSSHPublicKeyResponseTypeDef:
         """
-        [Client.send_serial_console_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send-serial-console-ssh-public-key)
         """
 
     def send_ssh_public_key(
         self, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
     ) -> SendSSHPublicKeyResponseTypeDef:
         """
-        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send-ssh-public-key)
         """
